==> uui-slider-0.0.14.tgz: package/lib/uui-slider.element.js <==
import { css, LitElement, html, svg, nothing } from 'lit';
import { query, property, state } from 'lit/decorators.js';
import { styleMap } from 'lit/directives/style-map.js';
import { UUIHorizontalPulseKeyframes, UUIHorizontalPulseAnimationValue } from '@umbraco-ui/uui-base/lib/animations';
import { UUIEvent } from '@umbraco-ui/uui-base/lib/events';
import { LabelMixin } from '@umbraco-ui/uui-base/lib/mixins';

const nativeInputStyles = css`
  input[type='range'] {
    left: 0;
    position: absolute;
    top: 0;
    height: 100%;
    width: 100%;
    z-index: 2;

    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
    border: none;
  }
  input[type='range']:focus {
    outline: none;
  }
  input[type='range']::-webkit-slider-runnable-track {
    width: 100%;
    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: none;
    background: transparent;
    color: transparent;
    overflow: visible;
    order: none;
  }

  input[type='range']:focus::-webkit-slider-runnable-track {
    background: transparent;
    border: none;
  }

  input[type='range']::-moz-range-track {
    width: 100%;
    height: 100%;
    -moz-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
  }

  input[type='range']::-ms-track {
    width: 100%;
    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
  }
  input[type='range']::-ms-fill-lower,
  input[type='range']::-ms-fill-upper {
    background: transparent;
    border: 0 none;
  }

  input[type='range']::-ms-tooltip {
    display: none;
  }

  input[type='range']::-moz-range-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
  }

  input[type='range']::-webkit-slider-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
    -webkit-appearance: none;
  }

  input[type='range']::-ms-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
  }

  input[type='range']:focus::-ms-fill-lower {
    background: transparent;
  }
  input[type='range']:focus::-ms-fill-upper {
    background: transparent;
  }
`;

class UUISliderEvent extends UUIEvent {
}
UUISliderEvent.INPUT = "input";

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
const renderSVG = (steps, stepWidth) => {
  return svg`
  ${steps.map((el) => {
    if (stepWidth / 6 >= 5)
      return svg`<circle class="uui-slider-circle" cx="${stepWidth * steps.indexOf(el)}" cy="50%" r="4.2" />`;
    return svg``;
  })}
`;
};
const renderValues = (steps, stepWidth, hide) => {
  if (hide)
    return html``;
  return html`<div id="steps-values">
    ${steps.map((el) => html` <span class="uui-slider-step">
          ${steps.length <= 20 && stepWidth / 6 >= 5 ? el.toFixed(0) : nothing}
        </span>`)}
  </div>`;
};
class UUISliderElement extends LabelMixin("label", LitElement) {
  constructor() {
    super();
    this.hideStepValues = false;
    this.min = 0;
    this.max = 100;
    this.step = 1;
    this._value = "";
    this.hideLabel = false;
    this.stepWidth = 0;
    this.onWindowResize = () => {
      this.stepWidth = this._calculateStepWidth();
    };
    this.steps = [];
    this.sliderPosition = "50%";
    this.fillScale = "0.5";
    this._range = (start, stop, step) => Array.from({ length: (stop - start) / step + 1 }, (_, i) => start + i * step);
    this._internals = this.attachInternals();
  }
  get value() {
    return this._value;
  }
  set value(newVal) {
    const oldVal = this._value;
    this._value = newVal;
    this._calculateSliderPosition(newVal);
    if ("ElementInternals" in window && "setFormValue" in window.ElementInternals.prototype) {
      this._internals.setFormValue(this._value);
    }
    this.requestUpdate("value", oldVal);
  }
  connectedCallback() {
    super.connectedCallback();
    window.addEventListener("resize", this.onWindowResize);
  }
  disconnectedCallback() {
    window.removeEventListener("resize", this.onWindowResize);
    super.disconnectedCallback();
  }
  firstUpdated() {
    this._updateSteps();
  }
  _updateSteps() {
    this.steps = this._range(this.min, this.max - 1, this.step);
    this.stepWidth = this._calculateStepWidth();
  }
  updated(changedProperties) {
    if (changedProperties.get("max") || changedProperties.get("min") || changedProperties.get("step"))
      this._updateSteps();
  }
  _calculateStepWidth() {
    return this.track.getBoundingClientRect().width / this.steps.length;
  }
  _calculateSliderPosition(newVal) {
    const ratio = (parseFloat(newVal) - this.min) / (this.max - this.min);
    this.fillScale = `${ratio}`;
    this.sliderPosition = `${Math.floor(ratio * 100)}%`;
  }
  _thumbDynamicStyles() {
    return { left: this.sliderPosition };
  }
  _onInput() {
    this.value = this.input.value;
    this.dispatchEvent(new UUISliderEvent(UUISliderEvent.INPUT));
  }
  render() {
    return html`
      <input
        type="range"
        min="${this.min}"
        max="${this.max}"
        .value="${this.value}"
        id="input1"
        aria-label="${this.label}"
        step="${+this.step}"
        @input=${this._onInput} />
      <div id="track" aria-hidden="true">
        <div id="stepper">
          <svg height="100%" width="100%" class="uui-slider-step">
            <line
              x1="0"
              y1="50%"
              x2="100%"
              y2="50%"
              stroke="black"
              id="slider-line" />
            ${renderSVG(this.steps, this.stepWidth)}
          </svg>
        </div>

        <div id="thumb" style=${styleMap(this._thumbDynamicStyles())}>
          <div id="value">${this.value}</div>
        </div>
      </div>
      ${renderValues(this.steps, this.stepWidth, this.hideStepValues)}
      ${this.hideLabel === false ? this.renderLabel() : ""}
    `;
  }
}
UUISliderElement.styles = [
  UUIHorizontalPulseKeyframes,
  nativeInputStyles,
  css`
      input[type='range'] {
        box-sizing: border-box;
      }

      :host {
        display: inline-block;
        width: 100%;
        position: relative;
        margin: 12px 0;
        min-height: 30px;
        border: none;
        -webkit-user-select: none;
           -moz-user-select: none;
            -ms-user-select: none;
                user-select: none;
      }

      #track {
        position: relative;
        top: 50%;
        height: 18px;
        width: 100%;
        display: flex;
      }

      #thumb {
        position: absolute;
        top: 0;
        bottom: 0;
        left: 0;
        height: 18px;
        width: 18px;
        background-color: transparent;
        border-radius: 50%;
        box-sizing: border-box;
        border: 1px solid var(--uui-interface-select,#3544B1);
        margin-left: -9px;
        transition: 0.1s left ease;
      }

      #thumb:after {
        content: '';
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translate(-50%, -50%);
        height: 9px;
        width: 9px;
        background-color: var(--uui-interface-select,#3544B1);
        border-radius: 50%;
      }

      #thumb:before {
        content: '';
        position: absolute;
        left: 50%;
        top: 50%;
        transform-origin: center center;
        transform: translate(-50%, -50%);
        height: 24px;
        width: 24px;
        background-color: transparent;
        border: 1px solid var(--uui-interface-select,#3544B1);
        border-radius: 50%;
        opacity: 0;
      }

      input:hover ~ #track #thumb:before {
        -webkit-animation: ${UUIHorizontalPulseAnimationValue};
                animation: ${UUIHorizontalPulseAnimationValue};
      }

      input:hover ~ #track #thumb:after {
        background-color: var(--uui-interface-select-hover,rgb(70, 86, 200));
      }

      input:hover ~ #track #thumb {
        border: 1px solid var(--uui-interface-select-hover,rgb(70, 86, 200));
      }

      #value {
        position: relative;
        box-sizing: border-box;
        font-weight: 600;
        bottom: 150%;
        width: 100%;
        text-align: center;
        opacity: 0;
        color: var(--uui-interface-select,#3544B1);
        transition: 0.2s opacity ease;
      }

      input:hover ~ #track #value {
        opacity: 1;
      }

      #track svg {
        opacity: 0.5;
        transition: 0.2s opacity ease;
      }

      input:focus ~ #track svg {
        opacity: 1;
      }

      #stepper {
        position: absolute;
        top: 0;
        bottom: 0;
        left: 0;
        width: 100%;
      }

      #steps-values {
        display: flex;
        align-items: flex-end;
        box-sizing: border-box;
      }

      #steps-values > span {
        flex-basis: 0;
        flex-grow: 1;
        transform: translateX(-50%);
        display: inline-block;
        text-align: center;
        font-size: 12px;
        color: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }

      #steps-values :first-child {
        opacity: 0;
      }

      svg > circle:first-of-type {
        fill: none;
      }

      #stepper {
        width: 100%;
      }

      #slider-line {
        stroke: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
        stroke-width: 1px;
      }

      .uui-slider-circle {
        fill: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }

      label {
        display: inline-block;
        margin-top: 6px;
        position: relative;

        font-weight: 2100;
      }

      @media (prefers-reduced-motion) {
        input:focus ~ #track #thumb:before {
          -webkit-animation: none;
                  animation: none;
        }

        label:before {
          transition: none;
        }
      }
    `
];
UUISliderElement.formAssociated = true;
__decorateClass([
  query("input")
], UUISliderElement.prototype, "input", 2);
__decorateClass([
  query("#track")
], UUISliderElement.prototype, "track", 2);
__decorateClass([
  property({ type: Boolean, attribute: "hide-step-values" })
], UUISliderElement.prototype, "hideStepValues", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "min", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "max", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "step", 2);
__decorateClass([
  property({ type: String })
], UUISliderElement.prototype, "value", 1);
__decorateClass([
  property({ type: Boolean, attribute: "hide-label", reflect: true })
], UUISliderElement.prototype, "hideLabel", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "stepWidth", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "steps", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "sliderPosition", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "fillScale", 2);

export { UUISliderElement };

==> uui-slider-0.0.16.tgz: package/lib/uui-slider.element.js <==
import { css, LitElement, html, svg, nothing } from 'lit';
import { query, property, state } from 'lit/decorators.js';
import { styleMap } from 'lit/directives/style-map.js';
import { UUIHorizontalPulseKeyframes, UUIHorizontalPulseAnimationValue } from '@umbraco-ui/uui-base/lib/animations';
import { UUIEvent } from '@umbraco-ui/uui-base/lib/events';
import { LabelMixin } from '@umbraco-ui/uui-base/lib/mixins';

const nativeInputStyles = css`
  input[type='range'] {
    left: 0;
    position: absolute;
    top: 0;
    height: 100%;
    width: 100%;
    z-index: 2;

    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
    border: none;
  }
  input[type='range']:focus {
    outline: none;
  }
  input[type='range']::-webkit-slider-runnable-track {
    width: 100%;
    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: none;
    background: transparent;
    color: transparent;
    overflow: visible;
    order: none;
  }

  input[type='range']:focus::-webkit-slider-runnable-track {
    background: transparent;
    border: none;
  }

  input[type='range']::-moz-range-track {
    width: 100%;
    height: 100%;
    -moz-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
  }

  input[type='range']::-ms-track {
    width: 100%;
    height: 100%;
    -webkit-appearance: none;
    margin: 0px;
    padding: 0px;
    border: 0 none;
    background: transparent;
    color: transparent;
    overflow: visible;
  }
  input[type='range']::-ms-fill-lower,
  input[type='range']::-ms-fill-upper {
    background: transparent;
    border: 0 none;
  }

  input[type='range']::-ms-tooltip {
    display: none;
  }

  input[type='range']::-moz-range-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
  }

  input[type='range']::-webkit-slider-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
    -webkit-appearance: none;
  }

  input[type='range']::-ms-thumb {
    width: 18px;
    height: 18px;
    border-radius: 12px;
    border: 0 none;
    background: transparent;
    cursor: pointer;
  }

  input[type='range']:focus::-ms-fill-lower {
    background: transparent;
  }
  input[type='range']:focus::-ms-fill-upper {
    background: transparent;
  }
`;

class UUISliderEvent extends UUIEvent {
}
UUISliderEvent.INPUT = "input";

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
typeof require !== "undefined" ? require : (x) => {
  throw new Error('Dynamic require of "' + x + '" is not supported');
};
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
const renderSVG = (steps, stepWidth) => {
  return svg`
  ${steps.map((el) => {
    if (stepWidth / 6 >= 5)
      return svg`<circle class="uui-slider-circle" cx="${stepWidth * steps.indexOf(el)}" cy="50%" r="4.2" />`;
    return svg``;
  })}
`;
};
const renderValues = (steps, stepWidth, hide) => {
  if (hide)
    return html``;
  return html`<div id="steps-values">
    ${steps.map((el) => html` <span class="uui-slider-step">
          ${steps.length <= 20 && stepWidth / 6 >= 5 ? el.toFixed(0) : nothing}
        </span>`)}
  </div>`;
};
class UUISliderElement extends LabelMixin("label", LitElement) {
  constructor() {
    super();
    this.hideStepValues = false;
    this.min = 0;
    this.max = 100;
    this.step = 1;
    this._value = "";
    this.hideLabel = false;
    this.stepWidth = 0;
    this.onWindowResize = () => {
      this.stepWidth = this._calculateStepWidth();
    };
    this.steps = [];
    this.sliderPosition = "50%";
    this.fillScale = "0.5";
    this._range = (start, stop, step) => Array.from({ length: (stop - start) / step + 1 }, (_, i) => start + i * step);
    this._internals = this.attachInternals();
  }
  get value() {
    return this._value;
  }
  set value(newVal) {
    const oldVal = this._value;
    this._value = newVal;
    this._calculateSliderPosition(newVal);
    if ("ElementInternals" in window && "setFormValue" in window.ElementInternals.prototype) {
      this._internals.setFormValue(this._value);
    }
    this.requestUpdate("value", oldVal);
  }
  connectedCallback() {
    super.connectedCallback();
    window.addEventListener("resize", this.onWindowResize);
  }
  disconnectedCallback() {
    window.removeEventListener("resize", this.onWindowResize);
    super.disconnectedCallback();
  }
  firstUpdated() {
    this._updateSteps();
  }
  _updateSteps() {
    this.steps = this._range(this.min, this.max - 1, this.step);
    this.stepWidth = this._calculateStepWidth();
  }
  updated(changedProperties) {
    if (changedProperties.get("max") || changedProperties.get("min") || changedProperties.get("step"))
      this._updateSteps();
  }
  _calculateStepWidth() {
    return this.track.getBoundingClientRect().width / this.steps.length;
  }
  _calculateSliderPosition(newVal) {
    const ratio = (parseFloat(newVal) - this.min) / (this.max - this.min);
    this.fillScale = `${ratio}`;
    this.sliderPosition = `${Math.floor(ratio * 100)}%`;
  }
  _thumbDynamicStyles() {
    return { left: this.sliderPosition };
  }
  _onInput() {
    this.value = this.input.value;
    this.dispatchEvent(new UUISliderEvent(UUISliderEvent.INPUT));
  }
  render() {
    return html`
      <input
        type="range"
        min="${this.min}"
        max="${this.max}"
        .value="${this.value}"
        id="input1"
        aria-label="${this.label}"
        step="${+this.step}"
        @input=${this._onInput} />
      <div id="track" aria-hidden="true">
        <div id="stepper">
          <svg height="100%" width="100%" class="uui-slider-step">
            <line
              x1="0"
              y1="50%"
              x2="100%"
              y2="50%"
              stroke="black"
              id="slider-line" />
            ${renderSVG(this.steps, this.stepWidth)}
          </svg>
        </div>

        <div id="thumb" style=${styleMap(this._thumbDynamicStyles())}>
          <div id="value">${this.value}</div>
        </div>
      </div>
      ${renderValues(this.steps, this.stepWidth, this.hideStepValues)}
      ${this.hideLabel === false ? this.renderLabel() : ""}
    `;
  }
}
UUISliderElement.styles = [
  UUIHorizontalPulseKeyframes,
  nativeInputStyles,
  css`
      input[type='range'] {
        box-sizing: border-box;
      }

      :host {
        display: inline-block;
        width: 100%;
        position: relative;
        margin: 12px 0;
        min-height: 30px;
        border: none;
        -webkit-user-select: none;
           -moz-user-select: none;
            -ms-user-select: none;
                user-select: none;
      }

      #track {
        position: relative;
        top: 50%;
        height: 18px;
        width: 100%;
        display: flex;
      }

      #thumb {
        position: absolute;
        top: 0;
        bottom: 0;
        left: 0;
        height: 18px;
        width: 18px;
        background-color: transparent;
        border-radius: 50%;
        box-sizing: border-box;
        border: 1px solid var(--uui-interface-select,#3544b1);
        margin-left: -9px;
        transition: 0.1s left ease;
      }

      #thumb:after {
        content: '';
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translate(-50%, -50%);
        height: 9px;
        width: 9px;
        background-color: var(--uui-interface-select,#3544b1);
        border-radius: 50%;
      }

      #thumb:before {
        content: '';
        position: absolute;
        left: 50%;
        top: 50%;
        transform-origin: center center;
        transform: translate(-50%, -50%);
        height: 24px;
        width: 24px;
        background-color: transparent;
        border: 1px solid var(--uui-interface-select,#3544b1);
        border-radius: 50%;
        opacity: 0;
      }

      input:hover ~ #track #thumb:before {
        -webkit-animation: ${UUIHorizontalPulseAnimationValue};
                animation: ${UUIHorizontalPulseAnimationValue};
      }

      input:hover ~ #track #thumb:after {
        background-color: var(--uui-interface-select-hover,rgb(70, 86, 200));
      }

      input:hover ~ #track #thumb {
        border: 1px solid var(--uui-interface-select-hover,rgb(70, 86, 200));
      }

      #value {
        position: relative;
        box-sizing: border-box;
        font-weight: 600;
        bottom: 150%;
        width: 100%;
        text-align: center;
        opacity: 0;
        color: var(--uui-interface-select,#3544b1);
        transition: 0.2s opacity ease;
      }

      input:hover ~ #track #value {
        opacity: 1;
      }

      #track svg {
        opacity: 0.5;
        transition: 0.2s opacity ease;
      }

      input:focus ~ #track svg {
        opacity: 1;
      }

      #stepper {
        position: absolute;
        top: 0;
        bottom: 0;
        left: 0;
        width: 100%;
      }

      #steps-values {
        display: flex;
        align-items: flex-end;
        box-sizing: border-box;
      }

      #steps-values > span {
        flex-basis: 0;
        flex-grow: 1;
        transform: translateX(-50%);
        display: inline-block;
        text-align: center;
        font-size: 12px;
        color: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }

      #steps-values :first-child {
        opacity: 0;
      }

      svg > circle:first-of-type {
        fill: none;
      }

      #stepper {
        width: 100%;
      }

      #slider-line {
        stroke: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
        stroke-width: 1px;
      }

      .uui-slider-circle {
        fill: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }

      label {
        display: inline-block;
        margin-top: 6px;
        position: relative;

        font-weight: 2100;
      }

      @media (prefers-reduced-motion) {
        input:focus ~ #track #thumb:before {
          -webkit-animation: none;
                  animation: none;
        }

        label:before {
          transition: none;
        }
      }
    `
];
UUISliderElement.formAssociated = true;
__decorateClass([
  query("input")
], UUISliderElement.prototype, "input", 2);
__decorateClass([
  query("#track")
], UUISliderElement.prototype, "track", 2);
__decorateClass([
  property({ type: Boolean, attribute: "hide-step-values" })
], UUISliderElement.prototype, "hideStepValues", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "min", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "max", 2);
__decorateClass([
  property({ type: Number })
], UUISliderElement.prototype, "step", 2);
__decorateClass([
  property({ type: String })
], UUISliderElement.prototype, "value", 1);
__decorateClass([
  property({ type: Boolean, attribute: "hide-label", reflect: true })
], UUISliderElement.prototype, "hideLabel", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "stepWidth", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "steps", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "sliderPosition", 2);
__decorateClass([
  state()
], UUISliderElement.prototype, "fillScale", 2);

export { UUISliderElement };
